==> spaceone_identity-0.1.1.post431-py3-none-any.whl: spaceone/identity/model/domain_owner_model.py <==
# -*- coding: utf-8 -*-

from mongoengine import *

from spaceone.core.error import *
from spaceone.core.model.mongo_model import MongoModel


class DomainOwner(MongoModel):
    owner_id = StringField(max_length=40, unique_with='domain_id', required=True)
    password = BinaryField()
    name = StringField(max_length=128)
    email = StringField(max_length=255)
    mobile = StringField(max_length=24)
    language = StringField(max_length=7, default='en')
    timezone = StringField(max_length=50, default='Etc/GMT')
    # roles = ListField(ReferenceField('Role'))
    last_accessed_at = DateTimeField(auto_now_add=True)
    created_at = DateTimeField(auto_now_add=True)
    domain_id = StringField(max_length=40)

    meta = {
        'updatable_fields': [
            'owner_id',
            'password',
            'name',
            'email',
            'mobile',
            'language',
            'timezone',
            'state',
            'roles'
        ],
        'exact_fields': [
            'owner_id',
            'domain_id'
        ],
        'minimal_fields': [
            'owner_id',
            'name',
            'state',
            'domain_id'
        ],
        'ordering': ['name'],
        'indexes': [
            'owner_id'
        ]
    }

    @classmethod
    def create(cls, data):
        user_vos = cls.filter(domain_id=data['domain_id'])
        if user_vos.count() > 0:
            raise ERROR_NOT_UNIQUE(key='owner_id', value=data['owner_id'])
        return super().create(data)

    def update(self, data):
        return super().update(data)

==> spaceone_identity-0.1.2.post3-py3-none-any.whl: spaceone/identity/model/domain_owner_model.py <==
# -*- coding: utf-8 -*-

from mongoengine import *

from spaceone.core.error import *
from spaceone.core.model.mongo_model import MongoModel


class DomainOwner(MongoModel):
    owner_id = StringField(max_length=40, unique_with='domain_id', required=True)
    password = BinaryField()
    name = StringField(max_length=128)
    email = StringField(max_length=255, default=None, null=True)
    mobile = StringField(max_length=24, default=None, null=True)
    language = StringField(max_length=7, default='en')
    timezone = StringField(max_length=50, default='Etc/GMT')
    domain_id = StringField(max_length=40)
    last_accessed_at = DateTimeField(auto_now_add=True)
    created_at = DateTimeField(auto_now_add=True)

    meta = {
        'updatable_fields': [
            'password',
            'name',
            'email',
            'mobile',
            'language',
            'timezone',
            'state'
        ],
        'exact_fields': [
            'owner_id',
            'domain_id'
        ],
        'minimal_fields': [
            'owner_id',
            'name',
            'state'
        ],
        'ordering': ['name'],
        'indexes': [
            'owner_id',
            'domain_id'
        ]
    }

    @classmethod
    def create(cls, data):
        user_vos = cls.filter(domain_id=data['domain_id'])
        if user_vos.count() > 0:
            raise ERROR_NOT_UNIQUE(key='owner_id', value=data['owner_id'])
        return super().create(data)

    def update(self, data):
        return super().update(data)
